.. image:: http://img94.imageshack.us/img94/9094/oscarza.jpg

===================================
Domain-driven e-commerce for Django
===================================

Oscar is an e-commerce framework for Django designed for building
domain-driven e-commerce sites.  It is structured such that any part of the
core functionality can be customised to suit the needs of your project.  This
allows it to handle a wide range of e-commerce requirements, from large-scale B2C
sites to complex B2B sites rich in domain-specific business logic.

Case studies
------------

Oscar is still in active development, but is used in production by a range of
companies, from large multinationals to small, boutique stores:

* Tata Group - http://www.landmarkonthenet.com
* Carlsberg - Their global "We Deliver More" platform is powered by Oscar (but
  is a B2B site so it not browsable by the public).
* Dolbeau - http://www.dolbeau.ca/
* The UK Labour party - http://shop.labour.org.uk (will be live in early June)

Many more on the way.

This README is just a stub - see the following links for more details
information:

* `Official homepage`_ 
* `Demo site`_ (experimental) 
* `Documentation`_ on `readthedocs.org`_
* `Google Group`_ - the mailing list is django-oscar@googlegroups.com
* `Continuous integration homepage`_ on `travis-ci.org`_
* `Twitter account for news and updates`_
* `Twitter account of all commits`_

.. image:: https://secure.travis-ci.org/tangentlabs/django-oscar.png

.. _`Official homepage`: http://oscarcommerce.com
.. _`Demo site`: http://sandbox.oscar.tangentlabs.co.uk
.. _`Documentation`: http://django-oscar.readthedocs.org/en/latest/
.. _`readthedocs.org`: http://readthedocs.org
.. _`Continuous integration homepage`: http://travis-ci.org/#!/tangentlabs/django-oscar 
.. _`travis-ci.org`: http://travis-ci.org/
.. _`Twitter account for news and updates`: https://twitter.com/#!/django_oscar
.. _`Twitter account of all commits`: https://twitter.com/#!/oscar_django
.. _`Google Group`: https://groups.google.com/forum/?fromgroups#!forum/django-oscar

Oscar was written by `David Winterbottom`_ (`@codeinthehole`_) and is developed
and maintained by `Tangent Labs`_, a London-based digital agency.

Oscar is released under the permissive `New BSD license`_.

.. _`David Winterbottom`: http://codeinthehole.com
.. _`@codeinthehole`: https://twitter.com/codeinthehole
.. _`Tangent Labs`: http://www.tangentlabs.co.uk
.. _`New BSD license`: https://github.com/tangentlabs/django-oscar/blob/master/LICENSE
